@@ -1,12 +1,15 @@
 ### R code from vignette source 'article.Rnw'
 
 ###################################################
-### code chunk number 1: article.Rnw:1-4
+### code chunk number 1: article.Rnw:1-7
 ###################################################
 # This should be set to FALSE in case you want to redo the sampling as well.
 # Default is TRUE to save CRAN some time.
 usePreCalcResults <- TRUE
 
+# Default here is FALSE because the object created is rather large
+usePreCalcResultsExtra <- FALSE 
+
 
 ###################################################
 ### code chunk number 2: preliminaries
@@ -20,35 +23,40 @@ options(prompt = 'R> ', continue = '+  ')
 set.seed(123)
 library("stochvol")
 data("exrates")
-ret <- logret(exrates$USD, demean=TRUE)
-par(mfrow=c(2, 1), mar = c(1.9, 1.9, 1.9, .5), mgp = c(2, .6, 0))
+ret <- logret(exrates$USD, demean = TRUE)
+par(mfrow = c(2, 1), mar = c(1.9, 1.9, 1.9, .5), mgp = c(2, .6, 0))
 plot(exrates$date, exrates$USD, type = 'l', main = "Price of 1 EUR in USD")
-plot(exrates$date[-1], ret, type = 'l', main = "Demeaned log-returns")
+plot(exrates$date[-1], ret, type = 'l', main = "Demeaned log returns")
 
 
 ###################################################
 ### code chunk number 4: usd2
 ###################################################
 sim <- svsim(500, mu = -9, phi = 0.99, sigma = 0.1)
-par(mfrow=c(2, 1))
+par(mfrow = c(2, 1))
 plot(sim)
 
 
 ###################################################
-### code chunk number 5: article.Rnw:219-221 (eval = FALSE)
+### code chunk number 5: article.Rnw:227-229 (eval = FALSE)
 ###################################################
 ## res <- svsample(ret, priormu = c(-10, 1), priorphi = c(20, 1.1),
 ##                 priorsigma = .1)
 
 
 ###################################################
-### code chunk number 6: article.Rnw:224-225
+### code chunk number 6: article.Rnw:232-238
 ###################################################
-res <- svsample(ret, priormu = c(-10, 1), priorphi = c(20, 1.1), priorsigma = .1)
+if (usePreCalcResultsExtra) {
+ load('vignette_sampling_draws1.RData')
+} else {
+ res <- svsample(ret, priormu = c(-10, 1), priorphi = c(20, 1.1), priorsigma = .1)
+ #save(res, file = 'vignette_sampling_draws1.RData')
+}
 
 
 ###################################################
-### code chunk number 7: article.Rnw:247-248
+### code chunk number 7: article.Rnw:260-261
 ###################################################
 summary(res, showlatent = FALSE)
 
@@ -83,7 +91,7 @@ paradensplot(res)
 ###################################################
 ### code chunk number 12: usd7
 ###################################################
-plot(res)
+plot(res, showobs = FALSE)
 
 
 ###################################################
@@ -94,21 +102,21 @@ plot(myresid, ret)
 
 
 ###################################################
-### code chunk number 14: article.Rnw:379-385
+### code chunk number 14: article.Rnw:392-398
 ###################################################
 set.seed(123456)
-T <- 1000
+n <- 1000
 beta.true <- c(.1, .5)
 sigma.true <- 0.01
-X <- matrix(c(rep(1, T), rnorm(T, sd = sigma.true)), nrow = T)
-y <- rnorm(T, X %*% beta.true, sigma.true)
+X <- matrix(c(rep(1, n), rnorm(n, sd = sigma.true)), nrow = n)
+y <- rnorm(n, X %*% beta.true, sigma.true)
 
 
 ###################################################
-### code chunk number 15: article.Rnw:389-395
+### code chunk number 15: article.Rnw:402-408
 ###################################################
-draws <- 5000
 burnin <- 100
+draws <- 5000
 b0 <- matrix(c(0, 0), nrow = ncol(X))
 B0inv <- diag(c(10^-10, 10^-10))
 c0 <- 0.001
@@ -116,16 +124,16 @@ C0 <- 0.001
 
 
 ###################################################
-### code chunk number 16: article.Rnw:398-402
+### code chunk number 16: article.Rnw:411-415
 ###################################################
 p <- ncol(X)
 preCov <- solve(crossprod(X) + B0inv)
 preMean <- preCov %*% (crossprod(X, y) + B0inv %*% b0)
-preDf <- c0 + T/2 + p/2
+preDf <- c0 + n/2 + p/2
 
 
 ###################################################
-### code chunk number 17: article.Rnw:405-408
+### code chunk number 17: article.Rnw:418-421
 ###################################################
 draws1 <- matrix(NA_real_, nrow = draws, ncol = p + 1)
 colnames(draws1) <- c(paste("beta", 0:(p-1), sep='_'), "sigma")
@@ -133,23 +141,22 @@ sigma2draw <- 1
 
 
 ###################################################
-### code chunk number 18: article.Rnw:411-418 (eval = FALSE)
+### code chunk number 18: article.Rnw:424-433 (eval = FALSE)
 ###################################################
 ## for (i in -(burnin-1):draws) {
-##  betadraw <- as.numeric(mvtnorm::rmvnorm(1, preMean, sigma2draw*preCov))
-##  tmp <- C0 + .5*(crossprod(y - X%*%betadraw) +
-##  		crossprod((betadraw - b0), B0inv) %*% (betadraw - b0))
-##  sigma2draw <- 1/rgamma(1, preDf, rate = tmp)
+##  betadraw <- as.numeric(mvtnorm::rmvnorm(1, preMean,
+## 					 sigma2draw * preCov))
+##  tmp <- C0 + .5 * (crossprod(y - X %*% betadraw) +
+##  		  crossprod((betadraw - b0), B0inv) %*%
+## 		   (betadraw - b0))
+##  sigma2draw <- 1 / rgamma(1, preDf, rate = tmp)
 ##  if (i > 0) draws1[i,] <- c(betadraw, sqrt(sigma2draw))
 ## }
 
 
 ###################################################
-### code chunk number 19: article.Rnw:420-432
+### code chunk number 19: article.Rnw:435-442
 ###################################################
-#if (file.exists('~/tmprary/article_draws1.RData')) {
-# load('~/tmprary/article_draws1.RData')
-#} else {
 for (i in -(burnin-1):draws) {
  betadraw <- as.numeric(mvtnorm::rmvnorm(1, preMean, sigma2draw*preCov))
  tmp <- C0 + .5*(crossprod(y - X%*%betadraw) +
@@ -157,35 +164,39 @@ for (i in -(burnin-1):draws) {
  sigma2draw <- 1/rgamma(1, preDf, rate = tmp)
  if (i > 0) draws1[i,] <- c(betadraw, sqrt(sigma2draw))
 }
-# save(draws1, file = '~/tmprary/article_draws1.RData')
-#}
 
 
 ###################################################
-### code chunk number 20: homo
+### code chunk number 20: article.Rnw:445-446
+###################################################
+colMeans(draws1)
+
+
+###################################################
+### code chunk number 21: homo
 ###################################################
 par(mar = c(3.1, 1.8, 1.9, .5), mgp = c(1.8, .6, 0))
 plot(coda::mcmc(draws1))
 
 
 ###################################################
-### code chunk number 21: article.Rnw:446-447
+### code chunk number 22: article.Rnw:454-455 (eval = FALSE)
 ###################################################
-colMeans(draws1)
+## plot(coda::mcmc(draws1))
 
 
 ###################################################
-### code chunk number 22: article.Rnw:458-463
+### code chunk number 23: article.Rnw:477-482
 ###################################################
 mu.true <- log(sigma.true^2)
 phi.true <- 0.97
-volvol.true <- 0.3
-simresid <- svsim(T, mu = mu.true, phi = phi.true, sigma = volvol.true)
+vv.true <- 0.3
+simresid <- svsim(n, mu = mu.true, phi = phi.true, sigma = vv.true)
 y <- X %*% beta.true + simresid$y
 
 
 ###################################################
-### code chunk number 23: article.Rnw:466-472
+### code chunk number 24: article.Rnw:485-491
 ###################################################
 draws <- 50000
 burnin <- 1000
@@ -196,23 +207,26 @@ priorsigma <- 1
 
 
 ###################################################
-### code chunk number 24: article.Rnw:475-480
+### code chunk number 25: article.Rnw:494-502
 ###################################################
-draws2 <- matrix(NA_real_, nrow = floor(draws/thinning), ncol = 3 + T + p)
-colnames(draws2) <- c("mu", "phi", "sigma", paste("beta", 0:(p-1), sep='_'),
-                      paste("h", 1:T, sep='_'))
+draws2 <- matrix(NA_real_, nrow = floor(draws / thinning),
+		 ncol = 3 + n + p)
+colnames(draws2) <- c("mu", "phi", "sigma",
+		      paste("beta", 0:(p-1), sep = '_'),
+                      paste("h", 1:n, sep='_'))
 betadraw <- c(0, 0)
-svdraw <- list(para = c(mu = -10, phi = .9, sigma = .2), latent = rep(-10, T))
+svdraw <- list(para = c(mu = -10, phi = .9, sigma = .2),
+	       latent = rep(-10, n))
 
 
 ###################################################
-### code chunk number 25: article.Rnw:483-500 (eval = FALSE)
+### code chunk number 26: article.Rnw:509-526 (eval = FALSE)
 ###################################################
 ## for (i in -(burnin-1):draws) {
 ##  ytilde <- y - X %*% betadraw
-##  svdraw <- .svsample(ytilde, startpara=para(svdraw),
-##                      startlatent=latent(svdraw), priormu=priormu,
-##                      priorphi=priorphi, priorsigma=priorsigma)
+##  svdraw <- svsample2(ytilde, startpara = para(svdraw),
+##                      startlatent = latent(svdraw), priormu = priormu,
+##                      priorphi = priorphi, priorsigma = priorsigma)
 ##  normalizer <- as.numeric(exp(-latent(svdraw)/2))
 ##  Xnew <- X * normalizer
 ##  ynew <- y * normalizer
@@ -222,13 +236,13 @@ svdraw <- list(para = c(mu = -10, phi = .9, sigma = .2), latent = rep(-10, T))
 ##  if (i > 0 & i %% thinning == 0) { 
 ##   draws2[i/thinning, 1:3] <- para(svdraw)
 ##   draws2[i/thinning, 4:5] <- betadraw
-##   draws2[i/thinning, 6:(T+5)] <- latent(svdraw)
+##   draws2[i/thinning, 6:(n+5)] <- latent(svdraw)
 ##  }
 ## }
 
 
 ###################################################
-### code chunk number 26: article.Rnw:503-532
+### code chunk number 27: article.Rnw:529-558
 ###################################################
 if (usePreCalcResults) {
  load('vignette_sampling_draws2.RData')
@@ -237,9 +251,9 @@ for (i in -(burnin-1):draws) {
 
  # draw latent volatilities and AR-parameters:
  ytilde <- y - X %*% betadraw
- svdraw <- .svsample(ytilde, startpara=para(svdraw),
-                     startlatent=latent(svdraw), priormu=priormu,
-                     priorphi=priorphi, priorsigma=priorsigma)
+ svdraw <- svsample2(ytilde, startpara = para(svdraw),
+                     startlatent = latent(svdraw), priormu = priormu,
+                     priorphi = priorphi, priorsigma = priorsigma)
 
  # draw the betas:
  normalizer <- as.numeric(exp(-latent(svdraw)/2))
@@ -253,7 +267,7 @@ for (i in -(burnin-1):draws) {
  if (i > 0 & i %% thinning == 0) { 
   draws2[i/thinning, 1:3] <- para(svdraw)
   draws2[i/thinning, 4:5] <- betadraw
-  draws2[i/thinning, 6:(T+5)] <- latent(svdraw)
+  draws2[i/thinning, 6:(n+5)] <- latent(svdraw)
  }
 }
  draws2selection <- draws2[,4:8]
@@ -262,45 +276,45 @@ for (i in -(burnin-1):draws) {
 
 
 ###################################################
-### code chunk number 27: article.Rnw:535-536 (eval = FALSE)
+### code chunk number 28: article.Rnw:561-562 (eval = FALSE)
+###################################################
+## colMeans(draws2[,4:8])
+
+
+###################################################
+### code chunk number 29: article.Rnw:565-566
+###################################################
+colMeans(draws2selection)
+
+
+###################################################
+### code chunk number 30: article.Rnw:569-570 (eval = FALSE)
 ###################################################
 ## plot(coda::mcmc(draws2[,4:7]))
 
 
 ###################################################
-### code chunk number 28: hetero
+### code chunk number 31: hetero
 ###################################################
 par(mar = c(3.1, 1.8, 1.9, .5), mgp = c(1.8, .6, 0))
 plot(coda::mcmc(draws2selection[,1:4]))
 
 
 ###################################################
-### code chunk number 29: article.Rnw:553-554 (eval = FALSE)
+### code chunk number 32: scatter
 ###################################################
-## colMeans(draws2[,4:8])
-
-
-###################################################
-### code chunk number 30: article.Rnw:557-558
-###################################################
-colMeans(draws2selection)
-
-
-###################################################
-### code chunk number 31: scatter
-###################################################
-x <- exrates$USD[-length(exrates$USD)]
-y <- exrates$USD[-1]
+x <- log(exrates$USD[-length(exrates$USD)])
+y <- log(exrates$USD[-1])
 X <- matrix(c(rep(1, length(x)), x), nrow = length(x))
 par(mfrow=c(1,1), mar = c(2.9, 2.9, 2.7, .5), mgp = c(1.8,.6,0), tcl = -.4)
-plot(x,y, xlab=expression(p[t]), ylab=expression(p[t+1]),
-    main="Scatterplot of lagged daily raw prices of 1 EUR in USD",
+plot(x,y, xlab=expression(log(p[t])), ylab=expression(log(p[t+1])),
+    main="Scatterplot of lagged daily log prices of 1 EUR in USD",
     col="#00000022", pch=16, cex=1)
 abline(0,1)
 
 
 ###################################################
-### code chunk number 32: article.Rnw:609-730
+### code chunk number 33: article.Rnw:650-871
 ###################################################
 if (usePreCalcResults) {
  load('vignette_sampling_realworld.RData')
@@ -332,8 +346,9 @@ C0 <- 0.001
 B0inv <- solve(B0)
 
 ## initialize some space to hold results:
-realres <- vector('list', 2)
+realres <- vector('list', 3)
 
+## AR(1)-SV:
 realres[[1]] <- matrix(NA_real_, nrow = floor(draws/thinning), ncol = 3 + n + p)
 colnames(realres[[1]]) <- c("mu", "phi", "sigma", paste("beta", 0:(p-1), sep='_'),
 			   paste("h", 1:n, sep='_'))
@@ -352,9 +367,9 @@ svdraw <- list(para = c(mu = -10, phi = .8, sigma = .2),
 tim <- system.time(
 for (i in -(burnin-1):draws) {
  if (i%%1000 == 0) cat("Iteration", i, "done.\n")
- # draw latent volatilities and AR-parameters:
+ # draw latent volatilities and SV-parameters:
  ytilde <- y - X %*% betadraw
- svdraw <- .svsample(ytilde, startpara=para(svdraw),
+ svdraw <- svsample2(ytilde, startpara=para(svdraw),
 		      startlatent=latent(svdraw), priormu=priormu,
 		      priorphi=priorphi, priorsigma=priorsigma)
 
@@ -375,7 +390,7 @@ for (i in -(burnin-1):draws) {
 }
 )[["elapsed"]]
 
-## standard sampler:
+## AR(1) homoskedastic:
 ## pre-calculate some values:
 preCov <- solve(crossprod(X) + B0inv)
 preMean <- preCov %*% (crossprod(X, y) + B0inv %*% b0)
@@ -409,61 +424,168 @@ for (i in -(burnin-1):draws) {
 }
 )[["elapsed"]]
 
+## AR(1)-GARCH(1,1):
+## allocate space:
+realres[[3]] <- matrix(NA_real_, nrow = floor(draws/thinning), ncol = 3 + n + p)
+colnames(realres[[3]]) <- c("a_0", "a_1", "b_1", paste("beta", 0:(p-1), sep='_'),
+			   paste("sigma", 1:n, sep='_'))
+
+## some auxiliary functions:
+loglik <- function(y, s2) {
+ sum(dnorm(y, 0, sqrt(s2), log=TRUE))
+}
+
+s2s <- function(y, para, y20, s20) {
+ s2 <- rep(NA_real_, length(y))
+ s2[1] <- para[1] + para[2]*y20 + para[3]*s20
+ for (i in 2:length(y)) s2[i] <- para[1] + para[2]*y[i-1]^2 + para[3]*s2[i-1]
+ s2	
+}
+
+## This is a very simple (and slow) random-walk MH sampler
+## which can most certainly be improved...
+
+## initial values:
+
+# crude approximation of residual variance:
+tmplm <- lm.fit(X, y)
+s20 <- var(resid(tmplm))
+
+y20 <- 0
+
+## starting values:
+## For the starting values for the parameters,
+## use ML results from fGarch::garchFit on the
+## residuals
+
+# tmpfit <- fGarch::garchFit(~garch(1,1), resid(tmplm), trace=FALSE)
+# startvals <- fGarch::coef(tmpfit)[c("omega", "alpha1", "beta1")]
+startvals <- c(1.532868e-07, 3.246417e-02, 9.644149e-01)
+
+## Random walk MH algorithm needs manual tuning for good mixing.
+## Gelman et al. (1996) suggest an acceptance rate of 31.6%
+## for spherical 3d multivariate normal (which we don't have :))
+## These values seem to work OK:
+# mhtuning <- tmpfit@fit$se.coef[c("omega", "alpha1", "beta1")] / 2
+mhtuning <- c(3.463851e-08, 2.226946e-03, 2.354829e-03)
+
+betadraw <- as.numeric(coef(tmplm))
+
+paradraw <- startvals
+paraprop <- rep(NA_real_, 3)
+ 
+s2draw <- rep(.1, length(y))
+s2prop <- rep(NA_real_, length(y))
+
+accepts <- 0
+
+## sampler:
+tim3 <- system.time(
+for (i in -(burnin-1):draws) {
+ 
+ if (i%%1000 == 0) cat("Iteration", i, "done.\n")
+ 
+ # draw volatilities and GARCH-parameters:
+ ytilde <- y - X %*% betadraw  # regression residuals
+
+ paraprop <- rnorm(3, paradraw, mhtuning)
+ s2prop <- s2s(ytilde, paraprop, y20, s20)
+
+ if (all(s2prop > 0)) { # s2 needs to be positive, otherwise reject
+  logR <- loglik(ytilde, s2prop) - loglik(ytilde, s2draw)  # log acceptance rate
+  if (log(runif(1)) < logR) {
+   paradraw <- paraprop
+   s2draw <- s2prop
+   if (i > 0) accepts <- accepts + 1
+  }
+ }
+
+ # draw the betas:
+ normalizer <- 1/sqrt(s2draw)
+ Xnew <- X * normalizer
+ ynew <- y * normalizer
+ Sigma <- solve(crossprod(Xnew) + B0inv)
+ mu <- Sigma %*% (crossprod(Xnew, ynew) + B0inv %*% b0)
+ betadraw <- as.numeric(mvtnorm::rmvnorm(1, mu, Sigma))
+
+ # store the results:
+ if (i > 0 & i %% thinning == 0) { 
+  realres[[3]][i/thinning, paras] <- paradraw
+  realres[[3]][i/thinning, latents] <- sqrt(s2draw)
+  realres[[3]][i/thinning, betas] <- betadraw
+ }
+}
+)[["elapsed"]]
+
+
 #Standardized residuals for model checking:
 #homoskedastic
 predmeans2 <- tcrossprod(X, realres[[2]][,1:2])
 standresidmeans2 <- rowMeans((y - predmeans2)/realres[[2]][,3])
 
-#heteroskedastic
+#heteroskedastic SV
 predmeans <- tcrossprod(X, realres[[1]][,4:5])
 standresidmeans <- rowMeans((y - predmeans)/exp(t(realres[[1]][,6:ncol(realres[[1]])])/2))
 
-realresselection <- vector('list', 2)
+#heteroskedastic GARCH
+predmeans3 <- tcrossprod(X, realres[[3]][,4:5])
+standresidmeans3 <- rowMeans((y - predmeans3)/t(realres[[3]][,6:ncol(realres[[3]])]))
+
+realresselection <- vector('list', 3)
 realresselection[[1]] <- realres[[1]][,c('beta_0', 'beta_1')]
 realresselection[[2]] <- realres[[2]][,c('beta_0', 'beta_1')]
-#save(realresselection, standresidmeans, standresidmeans2, file = 'vignette_sampling_realworld.RData')
+realresselection[[3]] <- realres[[3]][,c('beta_0', 'beta_1')]
+#save(realresselection, standresidmeans, standresidmeans2, standresidmeans3, file = 'vignette_sampling_realworld.RData')
 }
 
 
 ###################################################
-### code chunk number 33: betapost
+### code chunk number 34: betapost
 ###################################################
 smootherfactor <- 1.8
 par(mar = c(2.9, 2.9, 2.7, .5), mgp = c(1.8,.6,0), tcl = -.4)
 layout(matrix(c(1,2,3,3), byrow=TRUE, nrow=2))
 plot(density(realresselection[[1]][,"beta_0"], bw="SJ", adjust=smootherfactor),
-    main=bquote(paste("p(",beta[0],"|y)", sep="")),
-    xlab="", ylab="", xlim=c(-.0025, .0045))
-lines(density(realresselection[[2]][,"beta_0"], bw="SJ", adjust=smootherfactor), lty=2, col=2)
+    main=bquote(paste("p(",beta[0],"|",bold(y),")", sep="")),
+    xlab="", ylab="", xlim=c(-.0005, .001))
+lines(density(realresselection[[3]][,"beta_0"], bw="SJ", adjust=smootherfactor), lty=2, col=4)
+lines(density(realresselection[[2]][,"beta_0"], bw="SJ", adjust=smootherfactor), lty=3, col=2)
 #points(ols$coefficients[1],0, col=2)
 #lines(confint(ols)[1,], rep(0,2), col=2)
-legend("topleft", c("SV", "homosked."), col=1:2, lty=1:2)
+legend("topleft", c("SV", "GARCH", "homosked."), col=c(1,4,2), lty=1:3)
 
 plot(density(realresselection[[1]][,"beta_1"], bw="SJ", adjust=smootherfactor),
-    main=bquote(paste("p(",beta[1],"|y)", sep="")),
+    main=bquote(paste("p(",beta[1],"|",bold(y),")", sep="")),
     xlab="", ylab="", xlim=c(0.9965, 1.0022))
-lines(density(realresselection[[2]][,"beta_1"], bw="SJ", adjust=smootherfactor), lty=2, col=2)
+lines(density(realresselection[[3]][,"beta_1"], bw="SJ", adjust=smootherfactor), lty=2, col=4)
+lines(density(realresselection[[2]][,"beta_1"], bw="SJ", adjust=smootherfactor), lty=3, col=2)
 #points(ols$coefficients[2],0, col=2)
 #lines(confint(ols)[2,], rep(0,2), col=2)
-legend("topright", c("SV", "homosked."), col=1:2, lty=1:2)
+legend("topright", c("SV", "GARCH", "homosked."), col=c(1,4,2), lty=1:3)
 
-plotorder <- sample.int(2*nrow(realresselection[[1]]))
-cols <- rep(c("#00000055", "#ff000055"), each=nrow(realresselection[[1]]))[plotorder]
-pchs <- rep(1:2, each=nrow(realresselection[[1]]))[plotorder]
-beta0 <- c(realresselection[[1]][,"beta_0"], realresselection[[2]][,"beta_0"])[plotorder]
-beta1 <- c(realresselection[[1]][,"beta_1"], realresselection[[2]][,"beta_1"])[plotorder]
+plotorder <- sample.int(3*nrow(realresselection[[1]]))
+cols <- rep(c("#000000aa", "#0000ff66", "#ff000077"), each=nrow(realresselection[[1]]))[plotorder]
+pchs <- rep(1:3, each=nrow(realresselection[[1]]))[plotorder]
+
+beta0 <- c(realresselection[[1]][,"beta_0"],
+	   realresselection[[3]][,"beta_0"],
+	   realresselection[[2]][,"beta_0"])[plotorder]
+
+beta1 <- c(realresselection[[1]][,"beta_1"],
+	   realresselection[[3]][,"beta_1"],
+	   realresselection[[2]][,"beta_1"])[plotorder]
 
 plot(beta0, beta1, col=cols, pch=pchs,
-    xlab=bquote(paste("p(",beta[0],"|y)")),
-    ylab=bquote(paste("p(",beta[1],"|y)")),
+    xlab=bquote(paste("p(",beta[0],"|", bold(y), ")")),
+    ylab=bquote(paste("p(",beta[1],"|", bold(y), ")")),
     main="Scatterplot of posterior draws")
-legend("topright", c("SV", "homosked."), col=1:2, pch=1:2)
+legend("topright", c("SV", "GARCH", "homosked."), col=c(1,4,2), pch=1:3)
 
 
 ###################################################
-### code chunk number 34: qqplot
+### code chunk number 35: qqplot
 ###################################################
-par(mfrow=c(2,2), mar = c(3.1, 3.3, 2.0, .5), mgp = c(1.7,.5,0),
+par(mfrow=c(3,2), mar = c(3.1, 3.3, 2.0, .5), mgp = c(1.7,.5,0),
     tcl = -.4)
 plot(standresidmeans2, main="Residual scatterplot (homoskedastic errors)",
      xlab="Time", ylab="Standardized residuals")
@@ -471,6 +593,12 @@ qqplot(qnorm(ppoints(length(standresidmeans2)), mean=0, sd=1),
        standresidmeans2, main="Residual Q-Q plot (homoskedastic errors)",
        xlab = "Theoretical N(0,1)-quantiles", ylab = "Empirical Quantiles")
 abline(0,1)
+plot(standresidmeans3, main="Residual scatterplot (GARCH errors)",
+     xlab="Time", ylab="Standardized residuals")
+qqplot(qnorm(ppoints(length(standresidmeans3)), mean=0, sd=1),
+       standresidmeans3, main="Residual Q-Q plot (GARCH errors)",
+       xlab = "Theoretical N(0,1)-quantiles", ylab = "Empirical Quantiles")
+abline(0,1)
 plot(standresidmeans, main="Residual scatterplot (SV errors)",
      xlab="Time", ylab="Standardized residuals")
 qqplot(qnorm(ppoints(length(standresidmeans)), mean=0, sd=1),
